Type: Package
Package: overviewR
Title: Easily Extracting Information About Your Data
Version: 0.0.14
Authors@R: c(
    person("Cosima", "Meyer", , "cosima.meyer@gmail.com", role = c("cre", "aut")),
    person("Dennis", "Hammerschmidt", , "dennis_hammerschmidt@yahoo.com", role = "aut")
  )
Description: Makes it easy to display descriptive information on a data
    set.  Getting an easy overview of a data set by displaying and
    visualizing sample information in different tables (e.g., time and
    scope conditions).  The package also provides publishable 'LaTeX' code
    to present the sample information.
License: GPL-3
URL: https://github.com/cosimameyer/overviewR
BugReports: https://github.com/cosimameyer/overviewR/issues
Depends: R (>= 3.5.0)
Imports: data.table (>= 1.14.2), dplyr (>= 1.0.0), ggplot2 (>= 3.3.2),
        ggrepel (>= 0.8.2), ggvenn (>= 0.1.8), rlang, tibble (>=
        3.0.1), tidyr
Suggests: countrycode, covr, devtools, eulerr, knitr, magrittr,
        pkgdown, rmarkdown, spelling, testthat, xtable
VignetteBuilder: knitr, rmarkdown
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-05-05 06:32:21 UTC; cosima
Author: Cosima Meyer [cre, aut],
  Dennis Hammerschmidt [aut]
Maintainer: Cosima Meyer <cosima.meyer@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-05 06:50:02 UTC
Built: R 4.6.0; ; 2026-05-05 08:35:02 UTC; unix
