utils::globalVariables(
  c(
    "c1",
    "c2",
    "time_frame",
    "toydata",
    "count",
    "value",
    "count2",
    "grp",
    "n",
    "percentage",
    "total",
    "variable",
    "idx",
    "text",
    "quart4",
    "quart3",
    "quart2",
    "quart1",
    ".",
    "na_count",
    "..col_names",
    "..return_cols"
  )
)
