% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_markdown.R
\name{overview_markdown}
\alias{overview_markdown}
\title{overview_markdown}
\usage{
overview_markdown(
  obj,
  title = "Time and scope of the sample",
  id = "Sample",
  time = "Time frame",
  crosstab = FALSE,
  cond1 = "Condition 1",
  cond2 = "Condition 2",
  save_out = FALSE,
  file_path = ""
)
}
\arguments{
\item{obj}{Overview object produced by \code{overview_tab} or
\code{overview_crosstab}}

\item{title}{Optional title printed as a Markdown heading above the table.
Defaults to \code{"Time and scope of the sample"}.}

\item{id}{The header of the left column (default is \code{"Sample"}).
Ignored when \code{crosstab = TRUE}.}

\item{time}{The header of the right column (default is \code{"Time frame"}).
Ignored when \code{crosstab = TRUE}.}

\item{crosstab}{Logical. If \code{TRUE} produces a cross-table output.
Default is \code{FALSE}.}

\item{cond1}{Label for the first condition. Ignored when
\code{crosstab = FALSE}.}

\item{cond2}{Label for the second condition. Ignored when
\code{crosstab = FALSE}.}

\item{save_out}{Logical. If \code{TRUE} writes the output to a file.
Default is \code{FALSE}.}

\item{file_path}{Path (including file name with \code{.md} extension) where
the output is stored when \code{save_out = TRUE}.}
}
\value{
Invisibly returns a character string with the Markdown table. The
    table is also printed to the console (unless \code{save_out = TRUE}).
}
\description{
Produces a Markdown table output for objects obtained via
   \code{overview_tab} and \code{overview_crosstab}
}
\examples{
data(toydata)

overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
overview_markdown(obj = overview_object)

overview_ct_object <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
overview_markdown(
  obj = overview_ct_object,
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
}
